@@ -5,6 +5,9 @@ import subprocess
 import time
 import uuid
 import sem.utils
+import sys
+from importlib.machinery import SourceFileLoader
+import types
 
 from tqdm import tqdm
 
@@ -63,22 +66,25 @@ class SimulationRunner(object):
 
         # ns-3's build status output is used to get the executable path for the
         # specified script.
-        if optimized:
-            build_status_path = os.path.join(path,
-                                             'build/optimized/build-status.py')
+        if os.path.exists(os.path.join(self.path, "ns3")):
+            # In newer versions of ns-3 (3.36+), the name of the build status file is 
+            # platform-dependent
+            build_status_fname = ".lock-ns3_%s_build" % sys.platform
+            build_status_path = os.path.join(path, build_status_fname)
         else:
-            build_status_path = os.path.join(path,
-                                             'build/build-status.py')
+            build_status_fname = "build-status.py"
+            if optimized:
+                build_status_path = os.path.join(path,
+                                                'build/optimized/build-status.py')
+            else:
+                build_status_path = os.path.join(path,
+                                                'build/build-status.py')
 
         # By importing the file, we can naturally get the dictionary
-        try:  # This only works on Python >= 3.5
-            spec = importlib.util.spec_from_file_location('build_status',
-                                                          build_status_path)
-            build_status = importlib.util.module_from_spec(spec)
-            spec.loader.exec_module(build_status)
-        except (AttributeError):  # This happens in Python <= 3.4
-            import imp
-            build_status = imp.load_source('build_status', build_status_path)
+        loader = importlib.machinery.SourceFileLoader(build_status_fname, build_status_path)
+        mod = types.ModuleType(loader.name)
+        loader.exec_module(mod)
+            
 
         # Search is simple: we look for the script name in the program field.
         # Note that this could yield multiple matches, in case the script name
@@ -86,7 +92,7 @@ class SimulationRunner(object):
         # matches contains [program, path] for each program matching the script
         matches = [{'name': program,
                     'path': os.path.abspath(os.path.join(path, program))} for
-                   program in build_status.ns3_runnable_programs if self.script
+                   program in mod.ns3_runnable_programs if self.script
                    in program]
 
         if not matches:
@@ -103,7 +109,8 @@ class SimulationRunner(object):
         self.script_executable = max(match_percentages,
                                      key=lambda x: x['percentage'])['path']
 
-        if "scratch" in self.script_executable:
+        # This step is not needed for CMake versions of ns-3
+        if "scratch" in self.script_executable and not os.path.exists(os.path.join(self.path, "ns3")):
             path_with_subdir = self.script_executable.split("/scratch/")[-1]
             if ("/" in path_with_subdir):  # Script is in a subdir
                 executable_subpath = "%s/%s" % (self.script, self.script)
@@ -138,7 +145,7 @@ class SimulationRunner(object):
                 and only perform compilation.
         """
 
-        build_program = "ns3" if os.path.exists(os.path.join(self.path, "ns3")) else "waf"
+        build_program = "./ns3" if os.path.exists(os.path.join(self.path, "ns3")) else "./waf"
 
         # Only configure if necessary
         if not skip_configuration:
@@ -158,8 +165,7 @@ class SimulationRunner(object):
         j_argument = ['-j', str(self.max_parallel_processes)] if self.max_parallel_processes else []
         build_process = subprocess.Popen(['python3', build_program] + j_argument + ['build'],
                                          cwd=self.path,
-                                         stdout=subprocess.PIPE,
-                                         stderr=subprocess.PIPE)
+                                         stdout=subprocess.PIPE)
 
         # Show a progress bar
         if show_progress:
@@ -203,9 +209,8 @@ class SimulationRunner(object):
             if output == b'' and process.poll() is not None:
                 if process.returncode > 0:
                     raise Exception("Compilation ended with an error"
-                                    ".\nSTDERR\n%s\nSTDOUT\n%s" %
-                                    (process.stderr.read(),
-                                     process.stdout.read()))
+                                    ".\nSTDOUT\n%s" %
+                                    (process.stdout.read()))
                 return
             if output:
                 if build_program == "ns3":
